@@ -46,7 +46,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ApplyUserCert(self, request):
@@ -69,30 +69,53 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def CreateChaincodeAndInstallForUser(self, request):
-        """创建并安装合约
+    def DescribeFabricBlock(self, request):
+        """获取Fabric某区块的详细信息
 
-        :param request: Request instance for CreateChaincodeAndInstallForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.CreateChaincodeAndInstallForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.CreateChaincodeAndInstallForUserResponse`
+        :param request: Request instance for DescribeFabricBlock.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.DescribeFabricBlockRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.DescribeFabricBlockResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("CreateChaincodeAndInstallForUser", params, headers=headers)
+            body = self.call("DescribeFabricBlock", params, headers=headers)
             response = json.loads(body)
-            model = models.CreateChaincodeAndInstallForUserResponse()
+            model = models.DescribeFabricBlockResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeFabricTransaction(self, request):
+        """获取Fabric交易的详细信息
+
+        :param request: Request instance for DescribeFabricTransaction.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.DescribeFabricTransactionRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.DescribeFabricTransactionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFabricTransaction", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFabricTransactionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DownloadUserCert(self, request):
@@ -115,7 +138,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetBlockList(self, request):
@@ -138,7 +161,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetBlockTransactionListForUser(self, request):
@@ -161,122 +184,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetChaincodeCompileLogForUser(self, request):
-        """获取合约编译日志
-
-        :param request: Request instance for GetChaincodeCompileLogForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeCompileLogForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeCompileLogForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetChaincodeCompileLogForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetChaincodeCompileLogForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetChaincodeInitializeResultForUser(self, request):
-        """实例化结果查询
-
-        :param request: Request instance for GetChaincodeInitializeResultForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeInitializeResultForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeInitializeResultForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetChaincodeInitializeResultForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetChaincodeInitializeResultForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetChaincodeLogForUser(self, request):
-        """获取合约容器日志
-
-        :param request: Request instance for GetChaincodeLogForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeLogForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetChaincodeLogForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetChaincodeLogForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetChaincodeLogForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetChannelListForUser(self, request):
-        """获取通道列表
-
-        :param request: Request instance for GetChannelListForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetChannelListForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetChannelListForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetChannelListForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetChannelListForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetClusterListForUser(self, request):
-        """获取该用户的网络列表。网络信息中包含组织信息，但仅包含该用户所在组织的信息。
-
-        :param request: Request instance for GetClusterListForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetClusterListForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetClusterListForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetClusterListForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetClusterListForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetClusterSummary(self, request):
@@ -299,7 +207,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetInvokeTx(self, request):
@@ -322,7 +230,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetLatesdTransactionList(self, request):
@@ -345,7 +253,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetLatestTransactionList(self, request):
@@ -368,30 +276,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetPeerLogForUser(self, request):
-        """获取节点日志
-
-        :param request: Request instance for GetPeerLogForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetPeerLogForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetPeerLogForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetPeerLogForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetPeerLogForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetTransactionDetailForUser(self, request):
@@ -414,30 +299,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def InitializeChaincodeForUser(self, request):
-        """实例化合约
-
-        :param request: Request instance for InitializeChaincodeForUser.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.InitializeChaincodeForUserRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.InitializeChaincodeForUserResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("InitializeChaincodeForUser", params, headers=headers)
-            response = json.loads(body)
-            model = models.InitializeChaincodeForUserResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def Invoke(self, request):
@@ -460,7 +322,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InvokeChainMakerContract(self, request):
@@ -483,7 +345,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InvokeChainMakerDemoContract(self, request):
@@ -506,7 +368,30 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InvokeFabricChaincode(self, request):
+        """调用Fabric用户合约执行交易
+
+        :param request: Request instance for InvokeFabricChaincode.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.InvokeFabricChaincodeRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.InvokeFabricChaincodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InvokeFabricChaincode", params, headers=headers)
+            response = json.loads(body)
+            model = models.InvokeFabricChaincodeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def Query(self, request):
@@ -529,7 +414,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerBlockTransaction(self, request):
@@ -552,7 +437,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerContract(self, request):
@@ -575,7 +460,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerDemoBlockTransaction(self, request):
@@ -598,7 +483,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerDemoContract(self, request):
@@ -621,7 +506,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerDemoTransaction(self, request):
@@ -644,7 +529,7 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryChainMakerTransaction(self, request):
@@ -667,7 +552,30 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def QueryFabricChaincode(self, request):
+        """调用Fabric用户合约查询
+
+        :param request: Request instance for QueryFabricChaincode.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.QueryFabricChaincodeRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.QueryFabricChaincodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryFabricChaincode", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryFabricChaincodeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SrvInvoke(self, request):
@@ -690,4 +598,4 @@ class TbaasClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
